@@ -68,6 +68,7 @@ class MeteorClient(EventEmitter):
                 if error:
                     raise MeteorClientException('Failed to re-authenticate during reconnect')
                     return
+                self.connected = True
                 self._resubscribe()
             self.ddp_client.call('login', self._login_data, callback=reconnect_login_callback)
         else:
@@ -121,7 +122,7 @@ class MeteorClient(EventEmitter):
             'digest': hashed
         }
         self._login_data = [{'user': user_object, 'password': password_object}]
-        self.ddp_client.call('login', self._login_data, callback=callback)
+        self.ddp_client.call('login', self._login_data, callback=logged_in)
 
     def logout(self, callback=None):
         """Logout a user
